==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/TagEventFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TagEventFluentImpl<A extends io.fabric8.openshift.api.model.TagEventFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TagEventFluent<A>{
  public TagEventFluentImpl() {
  }
  public TagEventFluentImpl(io.fabric8.openshift.api.model.TagEvent instance) {
    this.withCreated(instance.getCreated()); 
    this.withDockerImageReference(instance.getDockerImageReference()); 
    this.withGeneration(instance.getGeneration()); 
    this.withImage(instance.getImage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String created;
  private java.lang.String dockerImageReference;
  private java.lang.Long generation;
  private java.lang.String image;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCreated() {
    return this.created;
  }
  public A withCreated(java.lang.String created) {
    this.created=created; return (A) this;
  }
  public java.lang.Boolean hasCreated() {
    return this.created != null;
  }
  
  /**
   * Method is deprecated. use withCreated instead.
   */
  @java.lang.Deprecated
  public A withNewCreated(java.lang.String arg0) {
    return (A)withCreated(new String(arg0));
  }
  public java.lang.String getDockerImageReference() {
    return this.dockerImageReference;
  }
  public A withDockerImageReference(java.lang.String dockerImageReference) {
    this.dockerImageReference=dockerImageReference; return (A) this;
  }
  public java.lang.Boolean hasDockerImageReference() {
    return this.dockerImageReference != null;
  }
  
  /**
   * Method is deprecated. use withDockerImageReference instead.
   */
  @java.lang.Deprecated
  public A withNewDockerImageReference(java.lang.String arg0) {
    return (A)withDockerImageReference(new String(arg0));
  }
  public java.lang.Long getGeneration() {
    return this.generation;
  }
  public A withGeneration(java.lang.Long generation) {
    this.generation=generation; return (A) this;
  }
  public java.lang.Boolean hasGeneration() {
    return this.generation != null;
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TagEventFluentImpl that = (TagEventFluentImpl) o;
    if (created != null ? !created.equals(that.created) :that.created != null) return false;
    if (dockerImageReference != null ? !dockerImageReference.equals(that.dockerImageReference) :that.dockerImageReference != null) return false;
    if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(created,  dockerImageReference,  generation,  image,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/TagEventFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TagEventFluentImpl<A extends io.fabric8.openshift.api.model.TagEventFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TagEventFluent<A>{
  public TagEventFluentImpl() {
  }
  public TagEventFluentImpl(io.fabric8.openshift.api.model.TagEvent instance) {
    this.withCreated(instance.getCreated()); 
    this.withDockerImageReference(instance.getDockerImageReference()); 
    this.withGeneration(instance.getGeneration()); 
    this.withImage(instance.getImage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String created;
  private java.lang.String dockerImageReference;
  private java.lang.Long generation;
  private java.lang.String image;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCreated() {
    return this.created;
  }
  public A withCreated(java.lang.String created) {
    this.created=created; return (A) this;
  }
  public java.lang.Boolean hasCreated() {
    return this.created != null;
  }
  
  /**
   * Method is deprecated. use withCreated instead.
   */
  @java.lang.Deprecated
  public A withNewCreated(java.lang.String arg0) {
    return (A)withCreated(new String(arg0));
  }
  public java.lang.String getDockerImageReference() {
    return this.dockerImageReference;
  }
  public A withDockerImageReference(java.lang.String dockerImageReference) {
    this.dockerImageReference=dockerImageReference; return (A) this;
  }
  public java.lang.Boolean hasDockerImageReference() {
    return this.dockerImageReference != null;
  }
  
  /**
   * Method is deprecated. use withDockerImageReference instead.
   */
  @java.lang.Deprecated
  public A withNewDockerImageReference(java.lang.String arg0) {
    return (A)withDockerImageReference(new String(arg0));
  }
  public java.lang.Long getGeneration() {
    return this.generation;
  }
  public A withGeneration(java.lang.Long generation) {
    this.generation=generation; return (A) this;
  }
  public java.lang.Boolean hasGeneration() {
    return this.generation != null;
  }
  public java.lang.String getImage() {
    return this.image;
  }
  public A withImage(java.lang.String image) {
    this.image=image; return (A) this;
  }
  public java.lang.Boolean hasImage() {
    return this.image != null;
  }
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0) {
    return (A)withImage(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TagEventFluentImpl that = (TagEventFluentImpl) o;
    if (created != null ? !created.equals(that.created) :that.created != null) return false;
    if (dockerImageReference != null ? !dockerImageReference.equals(that.dockerImageReference) :that.dockerImageReference != null) return false;
    if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(created,  dockerImageReference,  generation,  image,  additionalProperties,  super.hashCode());
  }
  
}
